@@ -108,7 +108,10 @@ def calculate_inverter_availability_and_loss(df , df_Pvsyst, P_exp):
     #
     aux_inv_exp = ava.loc[ (ava['Inv_ON'] == n_inv), [ 'Inv_ON','Inv_sum']  ]   #get inv sum where all inverters is on
     #####START BACK HERE CHRIS
-    aux_inv_exp['hour'] = aux_inv_exp.index.hour
+    try:
+        aux_inv_exp['hour'] = aux_inv_exp.index.hour
+    except AttributeError:
+        aux_inv_exp = aux_inv_exp.reindex(columns=aux_inv_exp.columns.to_list() + ['hour'])
     
     aux_inv_exp = aux_inv_exp.groupby( aux_inv_exp['hour'].values).mean() #get hourly average of inv sum
         
@@ -119,8 +122,10 @@ def calculate_inverter_availability_and_loss(df , df_Pvsyst, P_exp):
     #
     fill_inv = pd.DataFrame()
     fill_inv[aux.columns] = aux[aux['Inv_CUM_OFF_2'] == 1]
-    fill_inv['hour'] = fill_inv.index.hour
-    #
+    try:
+        fill_inv['hour'] = fill_inv.index.hour
+    except AttributeError:
+        fill_inv = fill_inv.reindex(columns=fill_inv.columns.to_list() + ['hour'])
     #
     aux_fill = []
     date_fill = []
