@@ -129,23 +129,32 @@ def run_bluesky(project_name, start=None, end=None, tran_ghi='add', plot=True):
         today = datetime.today()
         end = today - timedelta(days=1)
 
-    if tran_ghi != 'only':
+    if tran_ghi == 'only':
+        df_poa=blu.site_s3_to_poa(project_name, start, end)
+        df_cats = DataFrame(df_poa).rename(columns={'poa_global':'sites_ghi_poa'})
+        if plot:
+            df_cats['sites_ghi_poa'].plot()
+    else:
         df_cats,df_units=blu.solcats_to_dash(project_name,start,end,resample=True,convert=False)
-        df_cats = df_cats.tz_localize(None)
 
-    if tran_ghi != 'none':
-        try:
-            df_poa=blu.site_s3_to_poa(project_name, start, end).tz_convert(tz).tz_localize(None)
-            df_cats = DataFrame(df_poa).rename(columns={'poa_global':'sites_ghi_poa'})
-            df_cats.loc[:, 'site'] = project_name
-            if plot:
-                df_cats[['poa','ghi', 'sites_ghi_poa']].plot()
-        except IndexError:
-            print('No GHI to transpose! Solcast POA only')
+        if tran_ghi == 'none':
             if plot:
                 df_cats[['poa','ghi']].plot()
-        except FileNotFoundError:
-            pass
+        else:
+            try:
+                df_poa=blu.site_s3_to_poa(project_name, start, end)               
+                df_cats.loc[:, 'sites_ghi_poa'] = df_poa
+                if plot:
+                    df_cats[['poa','ghi', 'sites_ghi_poa']].plot()
+            except IndexError:
+                print('No GHI to transpose! Solcast POA only')
+                if plot:
+                    df_cats[['poa','ghi']].plot()
+            except FileNotFoundError:
+                pass
+
+    # Add project name to df so we can tell which site we're looking at
+    df_cats.loc[:, 'site'] = project_name
 
     print('\n')
     print('Solcast data successfully returned for {}'.format(project_name))
@@ -210,3 +219,8 @@ def update_config(func):
             self._parse_config_file()
         return func(self, *args, **kwargs)
     return check_config
+
+if __name__ == '__main__':
+    run_bluesky('Andrew Solar', start='2022-11-6', end='2022-11-6', tran_ghi='only', plot=True)
+    run_bluesky('Andrew Solar', start='2022-11-6', end='2022-11-6', tran_ghi='none', plot=True)
+    run_bluesky('Andrew Solar', start='2022-11-6', end='2022-11-6', tran_ghi='add', plot=True)
\ No newline at end of file
